@@ -1,6 +1,3 @@
-# coding=utf-8
-from __future__ import absolute_import
-
 from pkgutil import extend_path
 
 # noinspection PyUnboundLocalVariable
