@@ -1,19 +1,19 @@
-# coding=utf-8
 """Forum views."""
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 from datetime import datetime
+from typing import List, Union
 
-from abilian.i18n import _l
-from abilian.services.viewtracker import viewtracker
 from flask import g
 from flask_babel import format_date
 
+from abilian.i18n import _l
 from abilian.sbe.apps.communities.security import is_manager
+from abilian.sbe.apps.documents.models import Document
+from abilian.sbe.apps.wiki.models import WikiPage
+from abilian.services.viewtracker import viewtracker
 
 
-def object_viewers(entity):
+def object_viewers(entity: Union[Document, WikiPage]) -> List:
     if is_manager():
         views = viewtracker.get_views(entity=entity)
         community_members_id = [
@@ -26,9 +26,10 @@ def object_viewers(entity):
                     {"user": view.user, "viewed_at": view.hits[-1].viewed_at}
                 )
         return viewers
+    return []
 
 
-def activity_time_format(time, now=None):
+def activity_time_format(time: datetime, now: datetime = None) -> str:
     if not time:
         return ""
 
@@ -44,18 +45,18 @@ def activity_time_format(time, now=None):
     )
 
     if days == 0 and hours == 0 and minutes == 0:
-        return "{}{}".format(seconds, _l("s"))
+        return f"{seconds}{_l('s')}"
 
     if days == 0 and hours == 0:
-        return "{}{}".format(minutes, _l("m"))
+        return f"{minutes}{_l('m')}"
 
     if days == 0:
-        return "{}{}".format(hours, _l("h"))
+        return f"{hours}{_l('h')}"
 
     if days < 30:
-        return "{}{}".format(days, _l("d"))
+        return f"{days}{_l('d')}"
 
     if time.year == now.year:
-        return "{} {}".format(month_abbreviation, time.day)
+        return f"{month_abbreviation} {time.day}"
 
-    return "{} {}".format(month_abbreviation, str(time.year))
+    return f"{month_abbreviation} {str(time.year)}"
