@@ -1,8 +1,6 @@
-# coding=utf-8
-from __future__ import absolute_import, print_function, unicode_literals
+from flask_babel import lazy_gettext as _l
 
 from abilian.core.util import BasePresenter
-from flask_babel import lazy_gettext as _l
 
 
 class CommunityPresenter(BasePresenter):
