@@ -1,20 +1,20 @@
-# coding=utf-8
 """Tests from test_community are currently refactored using pytest in this
 module."""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
+from unittest import mock
 
 import pytest
-import six
 import sqlalchemy as sa
-from abilian.core.entities import Entity
-from abilian.core.models.subjects import User
-from abilian.testing.util import login
-from mock import MagicMock
+from flask.ctx import RequestContext
 from pytest import fixture
 from sqlalchemy import orm
+from sqlalchemy.orm import Session
 
+from abilian.core.entities import Entity
+from abilian.core.models.subjects import User
+from abilian.core.sqlalchemy import SQLAlchemy
+from abilian.sbe.app import Application
 from abilian.sbe.apps.documents.models import Folder
+from abilian.testing.util import login
 
 from .. import signals, views
 from ..models import MEMBER, READER, Community, CommunityIdColumn, \
@@ -22,7 +22,7 @@ from ..models import MEMBER, READER, Community, CommunityIdColumn, \
 
 
 @fixture
-def community(db_session):
+def community(db_session: Session) -> Community:
     community = Community(name="My Community")
     db_session.add(community)
     db_session.commit()
@@ -32,35 +32,29 @@ def community(db_session):
 #
 # Actual tests
 #
-def test_instanciation(db):
+def test_instanciation(db: SQLAlchemy) -> None:
     community = Community(name="My Community")
     assert isinstance(community.folder, Folder)
     # assert isinstance(community.group, Group)
 
 
-def test_default_view_kw():
+def test_default_view_kw() -> None:
     # test exceptions are handled if passed an object with 'community' attribute
     # and no community_id in kwargs. and ValueError is properly raised
-    if six.PY2:
-        dummy = type(b"Dummy", (object,), {b"community": None})()
-    else:
-        dummy = type("Dummy", (object,), {"community": None})()
+    dummy = type("Dummy", (object,), {"community": None})()
 
     with pytest.raises(ValueError) as exc_info:
         views.default_view_kw({}, dummy, "dummy", 1)
 
-    if six.PY2:
-        assert exc_info.value.message == "Cannot find community_id value"
-    else:
-        assert exc_info.value.args == ("Cannot find community_id value",)
+    assert exc_info.value.args == ("Cannot find community_id value",)
 
 
-def test_default_url(app, community):
+def test_default_url(app: Application, community: Community) -> None:
     url = app.default_view.url_for(community)
     assert url.endswith("/communities/my-community/")
 
 
-def test_can_recreate_with_same_name(community, db):
+def test_can_recreate_with_same_name(community: Community, db: SQLAlchemy) -> None:
     name = community.name
 
     db.session.delete(community)
@@ -74,28 +68,28 @@ def test_can_recreate_with_same_name(community, db):
     db.session.commit()
 
 
-def test_rename(community):
+def test_rename(community: Community) -> None:
     NEW_NAME = "My new name"
     community.rename(NEW_NAME)
     assert community.name == NEW_NAME
     assert community.folder.name == NEW_NAME
 
 
-def test_auto_slug(community):
+def test_auto_slug(community: Community) -> None:
     assert community.slug == "my-community"
 
 
-def test_membership(community, db):
+def test_membership(community: Community, db: SQLAlchemy) -> None:
     user = User(email="user@example.com")
 
     memberships = community.memberships
     assert memberships == []
 
     # setup signals testers with mocks.
-    when_set = MagicMock()
+    when_set = mock.MagicMock()
     when_set.mock_add_spec(["__name__"])  # required for signals
     signals.membership_set.connect(when_set)
-    when_removed = MagicMock()
+    when_removed = mock.MagicMock()
     when_removed.mock_add_spec(["__name__"])
     signals.membership_removed.connect(when_removed)
 
@@ -152,7 +146,7 @@ def test_membership(community, db):
     when_removed.assert_called_once_with(community, membership=membership)
 
 
-def test_folder_roles(community, db, app):
+def test_folder_roles(community: Community, db: SQLAlchemy, app: Application) -> None:
     user = User(email="user@example.com")
     folder = community.folder
     community.set_membership(user, "member")
@@ -167,7 +161,7 @@ def test_folder_roles(community, db, app):
     assert security.get_roles(user, folder) == ["reader"]
 
 
-def test_community_content_decorator(community, db):
+def test_community_content_decorator(community: Community, db: SQLAlchemy) -> None:
     @community_content
     class CommunityContent(Entity):
         community_id = CommunityIdColumn()
@@ -186,14 +180,13 @@ def test_community_content_decorator(community, db):
     assert cc.community_slug == "my-community"
     assert cc.slug == "my-content"
 
-    index_to = dict(CommunityContent.__indexation_args__["index_to"])
-    assert "community_slug" in index_to
-
 
 ##########################################################################
 
 
-def test_community_indexed(app, db):
+def test_community_indexed(
+    app: Application, db: SQLAlchemy, req_ctx: RequestContext
+) -> None:
     index_service = app.services["indexing"]
     index_service.start()
 
@@ -221,25 +214,26 @@ def test_community_indexed(app, db):
 
     db.session.commit()
 
-    with app.test_request_context():
-        with login(user_no_community):
-            res = index_service.search("community", object_types=obj_types)
-            assert len(res) == 0
+    with login(user_no_community):
+        res = index_service.search("community", object_types=obj_types)
+        assert len(res) == 0
 
-        with login(user):
-            res = index_service.search("community", object_types=obj_types)
-            assert len(res) == 1
-            hit = res[0]
-            assert hit["object_key"] == community1.object_key
+    with login(user):
+        res = index_service.search("community", object_types=obj_types)
+        assert len(res) == 1
+        hit = res[0]
+        assert hit["object_key"] == community1.object_key
 
-        with login(user_c2):
-            res = index_service.search("community", object_types=obj_types)
-            assert len(res) == 1
-            hit = res[0]
-            assert hit["object_key"] == community2.object_key
+    with login(user_c2):
+        res = index_service.search("community", object_types=obj_types)
+        assert len(res) == 1
+        hit = res[0]
+        assert hit["object_key"] == community2.object_key
 
 
-def test_default_view_kw_with_hit(app, db, community):
+def test_default_view_kw_with_hit(
+    app: Application, db: SQLAlchemy, community: Community, req_ctx: RequestContext
+) -> None:
     index_service = app.services["indexing"]
     index_service.start()
 
@@ -252,8 +246,7 @@ def test_default_view_kw_with_hit(app, db, community):
 
     obj_types = (Community.entity_type,)
 
-    with app.test_request_context():
-        with login(user):
-            hit = index_service.search("community", object_types=obj_types)[0]
-            kw = views.default_view_kw({}, hit, hit["object_type"], hit["id"])
-            assert kw == {"community_id": community.slug}
+    with login(user):
+        hit = index_service.search("community", object_types=obj_types)[0]
+        kw = views.default_view_kw({}, hit, hit["object_type"], hit["id"])
+        assert kw == {"community_id": community.slug}
