@@ -1,26 +1,32 @@
-# coding=utf-8
 """Celery tasks related to document transformation and preview."""
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 from contextlib import contextmanager
+from typing import TYPE_CHECKING, Iterator, Optional, Tuple
+
+from celery import shared_task
+from sqlalchemy.orm import Session
 
 from abilian.core.extensions import db
 from abilian.services import converter, get_service
 from abilian.services.conversion import ConversionError, HandlerNotFound
-from celery import shared_task
+
+if TYPE_CHECKING:
+    from .models import Document
 
 logger = logging.getLogger(__package__)
 
 
 @contextmanager
-def get_document(document_id, session=None):
+def get_document(
+    document_id: int, session: Optional[Session] = None
+) -> Iterator[Tuple[Session, Optional["Document"]]]:
     """Context manager that yields (session, document)."""
     from .models import Document
 
-    doc_session = session
     if session is None:
         doc_session = db.create_scoped_session()
+    else:
+        doc_session = session
 
     with doc_session.begin_nested():
         query = doc_session.query(Document)
@@ -34,7 +40,7 @@ def get_document(document_id, session=None):
 
 
 @shared_task
-def process_document(document_id):
+def process_document(document_id: int) -> None:
     """Run document processing chain."""
     with get_document(document_id) as (session, document):
         if document is None:
@@ -49,7 +55,7 @@ def process_document(document_id):
     convert_document_content.delay(document_id)
 
 
-def _run_antivirus(document):
+def _run_antivirus(document: "Document") -> Optional[bool]:
     antivirus = get_service("antivirus")
     if antivirus and antivirus.running:
         is_clean = antivirus.scan(document.content_blob)
@@ -69,7 +75,7 @@ def antivirus_scan(document_id):
 
 
 @shared_task
-def preview_document(document_id):
+def preview_document(document_id: int) -> None:
     """Compute the document preview images with its default preview size."""
     with get_document(document_id) as (session, document):
         if document is None:
@@ -91,7 +97,7 @@ def preview_document(document_id):
 
 
 @shared_task
-def convert_document_content(document_id):
+def convert_document_content(document_id: int) -> None:
     """Convert document content."""
     with get_document(document_id) as (session, doc):
         if doc is None:
@@ -103,7 +109,7 @@ def convert_document_content(document_id):
         extract_metadata(doc)
 
 
-def convert_to_pdf(doc):
+def convert_to_pdf(doc: "Document") -> None:
     error_kwargs = {"exc_info": True, "extra": {"stack": True}}
 
     if doc.content_type == "application/pdf":
@@ -113,7 +119,7 @@ def convert_to_pdf(doc):
             doc.pdf = converter.to_pdf(
                 doc.content_digest, doc.content, doc.content_type
             )
-        except HandlerNotFound as e:
+        except HandlerNotFound:
             doc.pdf = b""
         except ConversionError as e:
             doc.pdf = b""
@@ -125,7 +131,7 @@ def convert_to_pdf(doc):
             )
 
 
-def convert_to_text(doc):
+def convert_to_text(doc: "Document") -> None:
     error_kwargs = {"exc_info": True, "extra": {"stack": True}}
 
     try:
@@ -137,7 +143,7 @@ def convert_to_text(doc):
         )
 
 
-def extract_metadata(doc):
+def extract_metadata(doc: "Document") -> None:
     error_kwargs = {"exc_info": True, "extra": {"stack": True}}
 
     doc.extra_metadata = {}
