@@ -1,6 +1,3 @@
-# coding=utf-8
-from __future__ import absolute_import
-
 from . import documents, folders
 from .views import blueprint
 
