@@ -1,11 +1,6 @@
-# coding=utf-8
-from __future__ import absolute_import, print_function, unicode_literals
-
 import os.path
 import uuid
 
-from abilian.core.extensions import db
-from abilian.services import get_service
 from flask import Blueprint, request
 from flask_login import current_user
 from lxml.etree import XMLSyntaxError
@@ -13,6 +8,9 @@ from werkzeug.datastructures import Headers
 from werkzeug.exceptions import Forbidden, NotFound
 from werkzeug.wrappers import BaseResponse as Response
 
+from abilian.core.extensions import db
+from abilian.services import get_service
+
 from .. import repository
 from .constants import DAV_PROPS, HTTP_BAD_REQUEST, HTTP_CONFLICT, \
     HTTP_CREATED, HTTP_METHOD_NOT_ALLOWED, HTTP_MULTI_STATUS, \
@@ -30,7 +28,7 @@ __all__ = ["webdav"]
 
 
 # TODO: real logging
-class Logger(object):
+class Logger:
     def debug(self, msg):
         print(msg)
 
@@ -46,7 +44,7 @@ def log_request():
         print("")
         print(78 * "#")
         print(litmus_msg)
-        print("{} on {}".format(request.method, request.path))
+        print(f"{request.method} on {request.path}")
 
 
 @webdav.before_request
@@ -59,7 +57,7 @@ def only_admin():
 
 @webdav.after_request
 def log_response(response):
-    print("Response: {}".format(response))
+    print(f"Response: {response}")
     return response
 
 
@@ -116,7 +114,7 @@ def get(path):
     file_name = obj.file_name.encode("utf8")
     headers = {
         "Content-Type": obj.content_type,
-        "Content-Disposition": "attachment;filename=%s" % file_name,
+        "Content-Disposition": f"attachment;filename={file_name}",
     }
     return obj.content, HTTP_OK, headers
 
@@ -258,8 +256,7 @@ def lock(path):
 
     token = repository.lock(obj)
 
-    xml = (
-        """<?xml version="1.0" encoding="utf-8" ?>
+    xml = f"""<?xml version="1.0" encoding="utf-8" ?>
 <D:prop xmlns:D="DAV:">
     <D:lockdiscovery>
         <D:activelock>
@@ -269,15 +266,13 @@ def lock(path):
             <D:timeout>Second-179</D:timeout>
             <D:owner>flora</D:owner>
             <D:locktoken>
-                <D:href>opaquelocktoken:%s</D:href>
+                <D:href>opaquelocktoken:{token}</D:href>
             </D:locktoken>
         </D:activelock>
     </D:lockdiscovery>
 </D:prop>"""
-        % token
-    )
 
-    hlist = [("Content-Type", "text/xml"), ("Lock-Token", "<urn:uuid:%s>" % token)]
+    hlist = [("Content-Type", "text/xml"), ("Lock-Token", f"<urn:uuid:{token}>")]
 
     return Response(xml, headers=Headers.linked(hlist))  # , status ='423 Locked'
     # public Response lock(@Context UriInfo uriInfo) throws Exception {
