@@ -1,31 +1,29 @@
-# coding=utf-8
 """Models for the Forum.
 
 Note: a few features are planned but not implemented yet, and are commented
 out.
 """
-from __future__ import absolute_import, print_function, unicode_literals
-
 from collections import Counter
 from datetime import datetime
 from itertools import chain
+from typing import Any
 
-from abilian.core.entities import SEARCHABLE, Entity
-from abilian.services.indexing.adapter import SAAdapter
 from sqlalchemy import Column, ForeignKey, Integer, Unicode, UnicodeText
 from sqlalchemy.event import listens_for
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import backref, relationship
 from sqlalchemy.types import DateTime
 
+from abilian.core.entities import SEARCHABLE, Entity
 from abilian.sbe.apps.communities.models import Community, CommunityIdColumn, \
     community_content
-from abilian.sbe.apps.documents.models import BaseContent, CmisObject
+from abilian.sbe.apps.documents.models import BaseContent
+from abilian.services.indexing.adapter import SAAdapter
 
 
 class ThreadClosedError(RuntimeError):
     def __init__(self, thread):
-        super(ThreadClosedError, self).__init__(
+        super().__init__(
             "The thread {!r} is closed. No modification allowed on its posts: "
             "creation, edition, deletion".format(thread)
         )
@@ -160,11 +158,11 @@ class ThreadIndexAdapter(SAAdapter):
     """Index a thread and its posts."""
 
     @staticmethod
-    def can_adapt(obj_cls):
+    def can_adapt(obj_cls: Any) -> bool:
         return obj_cls is Thread
 
     def get_document(self, obj):
-        kw = super(ThreadIndexAdapter, self).get_document(obj)
+        kw = super().get_document(obj)
         kw["text"] = " ".join(chain((kw["text"],), [p.body_html for p in obj.posts]))
         return kw
 
@@ -206,8 +204,8 @@ def _guard_closed_thread_collection(thread, value, *args):
     return value
 
 
-class PostAttachment(BaseContent, CmisObject):
-    __tablename__ = None  # type: str
+class PostAttachment(BaseContent):
+    __tablename__: str = None
     __mapper_args__ = {"polymorphic_identity": "forum_post_attachment"}
     sbe_type = "forum_post:attachment"
 
