@@ -1,12 +1,6 @@
-# coding=utf-8
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 from abilian.core.entities import all_entity_classes
 from abilian.core.models.subjects import Group, User
-from six import text_type
-
-from ..models import Message, PrivateMessage
+from abilian.sbe.apps.social.models import Message, PrivateMessage
 
 
 def check_editable(object):
@@ -15,7 +9,7 @@ def check_editable(object):
             assert hasattr(object, k)
 
 
-def test_user():
+def test_user() -> None:
     user = User(
         first_name="John",
         last_name="Test User",
@@ -25,11 +19,11 @@ def test_user():
     check_editable(user)
 
     assert "John Test User" == user.name
-    assert "John Test User" == text_type(user)
+    assert "John Test User" == str(user)
     # self.assertEquals(len(user.messages), 0)
 
 
-def test_user_follow():
+def test_user_follow() -> None:
     # id is provided by DB (which is not used in this test), and is required for
     # having in (user1 != user2) == True
     user1 = User(
@@ -71,7 +65,7 @@ def test_user_follow():
     assert user2 not in user1.followers
 
 
-def test_group():
+def test_group() -> None:
     user = User(
         first_name="John",
         last_name="Test User",
@@ -95,7 +89,7 @@ def test_group():
     assert len(user.groups) == 0
 
 
-def test_private_message():
+def test_private_message() -> None:
     pm = PrivateMessage(creator_id=0, recipient_id=0)
     check_editable(pm)
 
@@ -121,12 +115,12 @@ def test_private_message():
 #     assert message.author_id == user.uid
 
 
-def test_tags():
+def test_tags() -> None:
     m = Message(content="abc #123 #cde #voilà_l_été #789")
     assert m.tags == ["123", "cde", "voilà_l_été", "789"]
 
 
-def test_get_all_entity_classes():
+def test_get_all_entity_classes() -> None:
     classes = all_entity_classes()
     assert Message in classes
     assert PrivateMessage in classes
