@@ -1,26 +1,25 @@
-# coding=utf-8
 """Forms for the Wiki module."""
-from __future__ import absolute_import, print_function, unicode_literals
+from typing import Any, Optional
+
+from wtforms import HiddenField, StringField, TextAreaField, ValidationError
+from wtforms.validators import data_required
 
 from abilian.i18n import _, _l
 from abilian.web.forms import Form
 from abilian.web.forms.filters import strip
 from abilian.web.forms.validators import flaghidden
 from abilian.web.forms.widgets import TextArea
-from flask import g
-from wtforms import HiddenField, StringField, TextAreaField
-from wtforms.validators import ValidationError, data_required
 
-from .models import WikiPage
+from .util import page_exists
 
 
-def clean_up(src):
+def clean_up(src: str) -> str:
     """Form filter."""
     src = src.replace("\r", "")
     return src
 
 
-def int_or_none(val):
+def int_or_none(val: Any) -> Optional[int]:
     try:
         return int(val)
     except (TypeError, ValueError):
@@ -42,14 +41,14 @@ class WikiPageForm(Form):
     page_id = HiddenField(filters=(int_or_none,), validators=[flaghidden()])
     last_revision_id = HiddenField(filters=(int_or_none,), validators=[flaghidden()])
 
-    def validate_title(self, field):
+    def validate_title(self, field: StringField) -> None:
         title = field.data
         if title != field.object_data and page_exists(title):
             raise ValidationError(
                 _("A page with this name already exists. Please use another name.")
             )
 
-    def validate_last_revision_id(self, field):
+    def validate_last_revision_id(self, field: HiddenField) -> None:
         val = field.data
         current = field.object_data
 
@@ -60,16 +59,6 @@ class WikiPageForm(Form):
             raise ValidationError(_("this page has been edited since"))
 
 
-def page_exists(title):
-    title = title.strip()
-    return (
-        WikiPage.query.filter(
-            WikiPage.community_id == g.community.id, WikiPage.title == title
-        ).count()
-        > 0
-    )
-
-
 # Not used yet
 class CommentForm(Form):
     message = TextAreaField(label=_l("Message"), validators=[data_required()])
