@@ -1,25 +1,23 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, print_function, unicode_literals
-
 from datetime import datetime
+from typing import Union
 
-from abilian.core.entities import SEARCHABLE, Entity, db
-from abilian.core.models.subjects import User
-from flask import g
+from flask_login import current_user
 from sqlalchemy import Column, DateTime, ForeignKey, Integer, Unicode, \
     UnicodeText, UniqueConstraint
 from sqlalchemy.event import listens_for
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import backref, relationship
+from sqlalchemy.orm.attributes import Event
+from sqlalchemy.util.langhelpers import _symbol
 
+from abilian.core.entities import Entity, db
+from abilian.core.models import SEARCHABLE
+from abilian.core.models.subjects import User
 from abilian.sbe.apps.communities.models import Community, CommunityIdColumn, \
     community_content
 from abilian.sbe.apps.documents.models import BaseContent
 
-from . import markup
-
-__all__ = ["WikiPage"]
+__all__ = ["WikiPage", "WikiPageAttachment", "WikiPageRevision"]
 
 
 @community_content
@@ -55,18 +53,18 @@ class WikiPage(Entity):
     # title is defined has an hybrid property to allow name <-> title sync
     # (2 way)
     @hybrid_property
-    def title(self):
+    def title(self: str) -> str:
         return self._title
 
     @title.setter
-    def title(self, title):
+    def title(self, title: str) -> None:
         # set title before setting name, so that we don't enter an infinite loop
         # with _wiki_sync_name_title
         self._title = title
         if self.name != title:
             self.name = title
 
-    def create_revision(self, body_src, message=""):
+    def create_revision(self, body_src: str, message: str = "") -> None:
         revision = WikiPageRevision()
         if self.revisions:
             revision.number = max(r.number for r in self.revisions) + 1
@@ -74,11 +72,11 @@ class WikiPage(Entity):
             revision.number = 0
         self.body_src = revision.body_src = body_src
         revision.message = message
-        revision.author = g.user
+        revision.author = current_user
         revision.page = self
 
     @property
-    def last_revision(self):
+    def last_revision(self) -> "WikiPageRevision":
         return (
             WikiPageRevision.query.filter(WikiPageRevision.page == self)
             .order_by(WikiPageRevision.number.desc())
@@ -86,7 +84,9 @@ class WikiPage(Entity):
         )
 
     @property
-    def body_html(self):
+    def body_html(self) -> str:
+        from . import markup
+
         html = markup.convert(self, self.body_src)
         return html
 
@@ -95,7 +95,9 @@ class WikiPage(Entity):
 
 
 @listens_for(WikiPage.name, "set", active_history=True)
-def _wiki_sync_name_title(entity, new_value, old_value, initiator):
+def _wiki_sync_name_title(
+    entity: WikiPage, new_value: str, old_value: Union[_symbol, str], initiator: Event
+) -> str:
     """Synchronize wikipage name -> title.
 
     wikipage.title -> name is done via hybrid_property, avoiding
@@ -136,7 +138,7 @@ class WikiPageRevision(db.Model):
 
 
 class WikiPageAttachment(BaseContent):
-    __tablename__ = None  # type: str
+    __tablename__: str = None
     __indexable__ = False
     __mapper_args__ = {"polymorphic_identity": "wikipage_attachment"}
     sbe_type = "wikipage:attachment"
