@@ -1,16 +1,30 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import difflib
 from pathlib import Path
+from typing import Any, Dict, Optional, Tuple, Union
+from urllib.parse import quote
 
 import sqlalchemy as sa
+from flask import current_app, flash, g, make_response, redirect, \
+    render_template, request
+from flask_login import current_user
+from markdown import markdown
+from markupsafe import Markup
+from sqlalchemy.orm.exc import NoResultFound
+from werkzeug.exceptions import NotFound
+from werkzeug.wrappers import Response
+from whoosh.searching import Hit
+
 from abilian.core.extensions import db
 from abilian.core.signals import activity
 from abilian.core.util import unwrap
 from abilian.i18n import _, _l, _n
+from abilian.sbe.apps.communities.blueprint import Blueprint
+from abilian.sbe.apps.communities.common import object_viewers
+from abilian.sbe.apps.communities.models import Community
+from abilian.sbe.apps.communities.presenters import CommunityPresenter
+from abilian.sbe.apps.communities.views import \
+    default_view_kw as community_dv_kw
+from abilian.services.security.models import Permission
 from abilian.services.viewtracker import viewtracker
 from abilian.web import csrf
 from abilian.web.action import Endpoint, actions
@@ -18,20 +32,7 @@ from abilian.web.nav import BreadcrumbItem
 from abilian.web.util import url_for
 from abilian.web.views import ObjectCreate, ObjectEdit, ObjectView, \
     default_view
-from flask import current_app, flash, g, make_response, redirect, \
-    render_template, request
-from flask_login import current_user
-from markdown import markdown
-from markupsafe import Markup
-from six import text_type
-from six.moves.urllib.parse import quote
-from sqlalchemy.orm.exc import NoResultFound
-from werkzeug.exceptions import NotFound
-from whoosh.searching import Hit
 
-from ..communities.blueprint import Blueprint
-from ..communities.common import object_viewers
-from ..communities.views import default_view_kw as community_dv_kw
 from .forms import WikiPageForm
 from .models import WikiPage, WikiPageAttachment, WikiPageRevision
 
@@ -40,7 +41,7 @@ route = wiki.route
 
 
 @wiki.url_value_preprocessor
-def init_wiki_values(endpoint, values):
+def init_wiki_values(endpoint: str, values: Dict[Any, Any]) -> None:
     g.current_tab = "wiki"
 
     endpoint = Endpoint("wiki.index", community_id=g.community.slug)
@@ -53,7 +54,7 @@ def init_wiki_values(endpoint, values):
 
 
 @route("/")
-def index():
+def index() -> Response:
     return redirect(url_for(".page", title="Home", community_id=g.community.slug))
 
 
@@ -72,29 +73,32 @@ def wiki_page_default_view_kw(kw, obj, obj_type, obj_id, **kwargs):
 #
 # Page level (all functions prefixed by 'page_').
 #
-class BasePageView(object):
+class BasePageView:
     Model = WikiPage
     pk = "title"
     Form = WikiPageForm
     base_template = "wiki/_base.html"
+    view_endpoint = ""
 
     @property
     def is_home_page(self):
         return self.obj is not None and self.obj.title == "Home"
 
     @property
-    def template_kwargs(self):
+    def template_kwargs(self) -> Dict[str, Union[WikiPageForm, WikiPage]]:
         """Template render arguments.
 
         You can override `base_template` for instance. Only `view` and
         `form` cannot be overriden.
         """
-        kw = super(BasePageView, self).template_kwargs
+        kw = super().template_kwargs
         kw["page"] = self.obj
         kw["viewers"] = object_viewers(self.obj)
         return kw
 
-    def init_object(self, args, kwargs):
+    def init_object(
+        self, args: Tuple[Any], kwargs: Dict[str, Any]
+    ) -> Tuple[Tuple[Any], Dict[str, Any]]:
         title = kwargs["title"] = request.args["title"].strip()
         if title:
             try:
@@ -117,7 +121,7 @@ class BasePageView(object):
     def index_url(self):
         return url_for(".index", community_id=g.community.slug)
 
-    def view_url(self):
+    def view_url(self) -> str:
         return url_for(
             self.view_endpoint, community_id=g.community.slug, title=self.obj.title
         )
@@ -130,7 +134,9 @@ class PageView(BasePageView, ObjectView):
         default_view(wiki, WikiPage, id_attr=None, kw_func=wiki_page_default_view_kw)
     ]
 
-    def init_object(self, args, kwargs):
+    def init_object(
+        self, args: Tuple[Any], kwargs: Dict[str, Any]
+    ) -> Tuple[Tuple[Any], Dict[str, Any]]:
         args, kwargs = BasePageView.init_object(self, args, kwargs)
         if not self.obj:
             title = kwargs["title"]
@@ -159,12 +165,14 @@ route("/viewers")(PageViewers.as_view("page_viewers"))
 class PageEdit(BasePageView, ObjectEdit):
     # template = 'wiki/page_edit.html'
     title = _("Edit page")
-    last_revision = None  # type: int
+    last_revision: int = None
     _message_success = _l("Wiki page successfully edited.")
 
-    def init_object(self, args, kwargs):
+    def init_object(
+        self, args: Tuple[Any], kwargs: Dict[str, Any]
+    ) -> Tuple[Tuple, Dict[str, Any]]:
         if request.method != "POST":
-            return super(PageEdit, self).init_object(args, kwargs)
+            return super().init_object(args, kwargs)
 
         page_id = request.form.get("page_id") or None
         if page_id is not None:
@@ -174,7 +182,7 @@ class PageEdit(BasePageView, ObjectEdit):
 
         return args, kwargs
 
-    def get_form_kwargs(self):
+    def get_form_kwargs(self) -> Dict[str, Union[WikiPage, Permission, int]]:
         kwargs = ObjectEdit.get_form_kwargs(self)
         kwargs["page_id"] = kwargs["last_revision_id"] = None
         if self.obj is not None and self.obj.id:
@@ -185,8 +193,10 @@ class PageEdit(BasePageView, ObjectEdit):
             kwargs["last_revision_id"] = self.obj.last_revision.id
         return kwargs
 
-    def prepare_args(self, args, kwargs):
-        super(PageEdit, self).prepare_args(args, kwargs)
+    def prepare_args(
+        self, args: Tuple[Any], kwargs: Dict[str, Any]
+    ) -> Tuple[Tuple, Dict[str, Any]]:
+        super().prepare_args(args, kwargs)
         last_revision_id = self.form.last_revision_id.data
         if last_revision_id:
             self.last_revision = WikiPageRevision.query.filter(
@@ -195,19 +205,21 @@ class PageEdit(BasePageView, ObjectEdit):
             ).first()
         return args, kwargs
 
-    def before_populate_obj(self):
+    def before_populate_obj(self) -> None:
         self.redirect_if_no_change()
         form = self.form
         self.obj.create_revision(form.body_src.data, form.message.data)
 
-    def redirect_if_no_change(self):
+    # FIXME: does nothing !
+    def redirect_if_no_change(self) -> Optional[Response]:
         form = self.form
         if all(f.data == f.object_data for f in (form.title, form.body_src)):
             flash(_("You didn't make any change to this page."))
             return self.redirect(url_for(self.obj))
+        return None
 
     @property
-    def activity_target(self):
+    def activity_target(self) -> Union[CommunityPresenter, Community]:
         return self.obj.community
 
     def form_invalid(self):
@@ -263,7 +275,9 @@ class PageCreate(PageEdit, ObjectCreate):
 
     get_form_kwargs = ObjectCreate.get_form_kwargs
 
-    def init_object(self, args, kwargs):
+    def init_object(
+        self, args: Tuple[Any], kwargs: Dict[str, Any]
+    ) -> Tuple[Tuple[Any], Dict[str, Any]]:
         args, kwargs = ObjectCreate.init_object(self, args, kwargs)
         self.obj.community = g.community
         session = sa.orm.object_session(self.obj)
@@ -278,7 +292,7 @@ route("/new")(PageCreate.as_view("page_new", view_endpoint=".page"))
 
 
 @route("/source/")
-def page_source():
+def page_source() -> Union[str, Response]:
     title = request.args["title"].strip()
     try:
         page = get_page_by_title(title)
@@ -292,7 +306,7 @@ def page_source():
 
 
 @route("/changes/")
-def page_changes():
+def page_changes() -> Union[str, Response]:
     title = request.args["title"].strip()
     try:
         page = get_page_by_title(title)
@@ -306,7 +320,7 @@ def page_changes():
 
 
 @route("/compare/")
-def page_compare():
+def page_compare() -> Union[str, Response]:
     title = request.args["title"].strip()
     try:
         page = get_page_by_title(title)
@@ -336,15 +350,15 @@ def page_compare():
 
     differ = difflib.Differ(charjunk=difflib.IS_CHARACTER_JUNK)
     diff = differ.compare(from_lines, to_lines)
-    diff = [line for line in diff if not line.startswith("?")]
+    diff_lines = [line for line in diff if not line.startswith("?")]
 
     actions.context["object"] = page
-    ctx = {"page": page, "diff": diff, "rev1": from_rev, "rev2": to_rev}
+    ctx = {"page": page, "diff": diff_lines, "rev1": from_rev, "rev2": to_rev}
     return render_template("wiki/compare.html", **ctx)
 
 
 @route("/delete/", methods=["POST"])
-def page_delete():
+def page_delete() -> Response:
     title = request.form["title"].strip()
     try:
         page = get_page_by_title(title)
@@ -356,7 +370,7 @@ def page_delete():
 
     app = unwrap(current_app)
     community = g.community._model
-    activity.send(app, actor=g.user, verb="delete", object=page, target=community)
+    activity.send(app, actor=current_user, verb="delete", object=page, target=community)
 
     db.session.commit()
     flash(_("Page %(title)s deleted.", title=title))
@@ -364,7 +378,7 @@ def page_delete():
 
 
 @route("/attachments")
-def attachment_download():
+def attachment_download() -> Response:
     title = request.args["title"].strip()
     attachment_id = int(request.args["attachment"])
     try:
@@ -379,16 +393,15 @@ def attachment_download():
     response = make_response(attachment.content)
     response.headers["content-length"] = attachment.content_length
     response.headers["content-type"] = attachment.content_type
-    content_disposition = 'attachment;filename="{}"'.format(
-        quote(attachment.name.encode("utf8"))
-    )
+    filename = quote(attachment.name.encode("utf8"))
+    content_disposition = f'attachment;filename="{filename}"'
     response.headers["content-disposition"] = content_disposition
     return response
 
 
 @route("/attachments", methods=["POST"])
 @csrf.protect
-def attachment_upload():
+def attachment_upload() -> Response:
     title = request.args["title"].strip()
     try:
         page = get_page_by_title(title)
@@ -400,8 +413,8 @@ def attachment_upload():
 
     for f in files:
         name = f.filename
-        if not isinstance(name, text_type):
-            name = text_type(f.filename, encoding="utf-8", errors="ignore")
+        if not isinstance(name, str):
+            name = str(f.filename, encoding="utf-8", errors="ignore")
 
         # FIXME: do something instead of just skipping the attachement
         if not name:
@@ -482,7 +495,7 @@ def wiki_export():
 #
 # Util
 #
-def get_page_by_title(title):
+def get_page_by_title(title: str) -> WikiPage:
     title = title.strip()
     page = WikiPage.query.filter(
         WikiPage.community_id == g.community.id, WikiPage.title == title
@@ -490,7 +503,7 @@ def get_page_by_title(title):
     return page
 
 
-def create_home_page():
+def create_home_page() -> WikiPage:
     path = Path(__file__).parent / "data" / "default_page.txt"
     default_src = path.open("rt").read()
     page = WikiPage(title="Home", body_src=default_src)
